@@ -44,8 +44,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 #ifndef HAVE_WINDOWS
+#include <inttypes.h>
 #include <sys/errno.h>
+#else
+#define PRId64 "I64d"
 #endif
 
 #include <getopt.h>
@@ -133,9 +137,8 @@ static int decode_switches (int argc, char **argv) {
 	
 int main(int argc, char *argv[])
 {
-  AVFormatContext *ic;
+  AVFormatContext *ic = NULL;
   AVCodec *p;
-  AVInputFormat *file_iformat = NULL;
   int err, ret, i, flags;
   char str[80];
   char *fn = NULL;
@@ -152,9 +155,9 @@ int main(int argc, char *argv[])
   av_log_set_level(AV_LOG_QUIET);
 
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(53, 7, 0)
-  err = av_open_input_file(&ic, fn, file_iformat, 0, NULL);
+  err = av_open_input_file(&ic, fn, NULL, 0, NULL);
 #else
-  err = avformat_open_input(&ic, fn, file_iformat, NULL);
+  err = avformat_open_input(&ic, fn, NULL, NULL);
 #endif
   if (err < 0) {
     fprintf(stderr, "%s: Error while opening file\n", fn);
@@ -177,7 +180,7 @@ int main(int argc, char *argv[])
 #endif
 
   if (want_mode == 1) { /* duration only */
-    printf("%lld", secs);
+    printf("%"PRId64"", secs);
     return 0;
   }
 
@@ -198,7 +201,7 @@ int main(int argc, char *argv[])
 	hours = mins / 60;
 	mins %= 60;
 
-	printf("%02lld:%02lld:%02lld.%01lld - ", hours, mins, secs, (us * 10) / AV_TIME_BASE);
+	printf("%02"PRId64":%02"PRId64":%02"PRId64".%01"PRId64" - ", hours, mins, secs, (us * 10) / AV_TIME_BASE);
 #if LIBAVFORMAT_BUILD < 4624 
 	printf("fps:%.2f ", (double) codec->frame_rate / (double) codec->frame_rate_base);
 #elif LIBAVFORMAT_BUILD <= 4629
@@ -232,7 +235,7 @@ int main(int argc, char *argv[])
 #endif
       p = avcodec_find_decoder(codec->codec_id);
       if (codec->width) {
-	printf("%lld,", secs);
+	printf("%"PRId64",", secs);
 	printf("%.2f,",1.0/av_q2d(st->time_base));
 #if LIBAVFORMAT_BUILD < 4624 
 	printf("%.2f,", (double) codec->frame_rate / (double) codec->frame_rate_base);
@@ -263,8 +266,8 @@ int main(int argc, char *argv[])
   printf("<av>\n");
   printf("  <xmlversion>0.2</xmlversion>\n");
   printf("  <filename>%s</filename>\n", ic->filename);
-  printf("  <length>%lld</length>\n", secs);
-  printf("  <duration>%lld</duration>\n", ic->duration);
+  printf("  <length>%"PRId64"</length>\n", secs);
+  printf("  <duration>%"PRId64"</duration>\n", ic->duration);
   printf("  <avtimebase>%d</avtimebase>\n", AV_TIME_BASE);
 
   us = ic->duration % AV_TIME_BASE;
@@ -273,12 +276,12 @@ int main(int argc, char *argv[])
   hours = mins / 60;
   mins %= 60;
 
-  printf("  <time>%02lld:%02lld:%02lld.%01lld</time>\n", hours, mins, secs, (us * 10) / AV_TIME_BASE);
+  printf("  <time>%02"PRId64":%02"PRId64":%02"PRId64".%01"PRId64"</time>\n", hours, mins, secs, (us * 10) / AV_TIME_BASE);
   printf("  <bitrate>%d</bitrate>\n", ic->bit_rate);
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(54, 0, 0)
-  printf("  <size>%lld</size>\n", ic->file_size);
+  printf("  <size>%"PRId64"</size>\n", ic->file_size);
 #endif
-  printf("  <startoffset>%lld</startoffset>\n", ic->start_time);
+  printf("  <startoffset>%"PRId64"</startoffset>\n", ic->start_time);
 #if LIBAVFORMAT_BUILD < 3473920
   if (ic->title) printf("  <title>%s</title>\n", ic->title);
 
@@ -341,7 +344,7 @@ int main(int argc, char *argv[])
     if (p) printf("    <codec>%s</codec>\n", p->name);
     else printf("    <codec>unknown</codec>\n");
 
-    printf("    <duration>%lld</duration>\n", st->duration);
+    printf("    <duration>%"PRId64"</duration>\n", st->duration);
     printf("    <timebase>\n      <numerator>%d</numerator>\n", st->time_base.num);
     printf("      <denominator>%d</denominator>\n    </timebase>\n", st->time_base.den);
     printf("    <timerate>%.2f</timerate>\n", 1.0/av_q2d(st->time_base));
