@@ -33,6 +33,7 @@
  */
 #include "xjadeo.h"
 #include "ffcompat.h"
+#include "remote.h"
 
 //------------------------------------------------
 // extern Globals (main.c)
@@ -231,7 +232,9 @@ void event_loop(void) {
 		long curFrame = dispFrame;
 		display_frame((int64_t)(offFrame), force_redraw, !splashed || want_nosplash);
 
-		if ((remote_en||mq_en||ipc_queue) && ((remote_mode&1) || ((remote_mode&2)&& curFrame!=dispFrame)) ) {
+		if ((remote_en||mq_en||ipc_queue)
+				&& ( (remote_mode&NTY_FRAMELOOP) || ((remote_mode&NTY_FRAMECHANGE)&& curFrame!=dispFrame))
+				) {
 		/*call 	xapi_pposition ?? -> rv:200
 		 * dispFrame is the currently displayed frame 
 		 * = SMPTE + offset
@@ -276,6 +279,16 @@ void event_loop(void) {
 		clock1.tv_sec=clock2.tv_sec;
 		clock1.tv_usec=clock2.tv_usec;
 	} 
+	if ((remote_en||mq_en||ipc_queue) && (remote_mode&4)) {
+		// send current settings
+		xapi_pfullscreen(NULL);
+		xapi_pontop(NULL);
+		xapi_posd(NULL);
+		xapi_pletterbox(NULL);
+		xapi_pwinpos(NULL);
+		xapi_pwinsize(NULL);
+		xapi_poffset(NULL);
+	}
 }
 
 //--------------------------------------------
@@ -299,9 +312,9 @@ void init_moviebuffer(void) {
 
 // Assign appropriate parts of buffer to image planes in pFrameFMT
 	if (pFrameFMT) {
-		avpicture_fill((AVPicture *)pFrameFMT, buffer, render_fmt, pCodecCtx->width, pCodecCtx->height);
+		avpicture_fill((AVPicture *)pFrameFMT, buffer, render_fmt, movie_width, movie_height);
 #ifdef HAVE_SWSCALE
-		pSWSCtx = sws_getContext(pCodecCtx->width, pCodecCtx->height, pCodecCtx->pix_fmt, pCodecCtx->width, pCodecCtx->height, render_fmt, SWS_BICUBIC, NULL, NULL, NULL);
+		pSWSCtx = sws_getContext(pCodecCtx->width, pCodecCtx->height, pCodecCtx->pix_fmt, movie_width, movie_height, render_fmt, SWS_BICUBIC, NULL, NULL, NULL);
 #endif
 	}
 	render_empty_frame(0);
@@ -445,7 +458,7 @@ int open_movie(char* file_name) {
 			fprintf(stdout, "original frame rate: %g\n", framerate);
 		fprintf(stdout, "length in seconds: %g\n", duration);
 		fprintf(stdout, "total frames: %ld\n", frames);
-		fprintf(stdout, "file start offset: %lld video-frames\n",file_frame_offset);
+		fprintf(stdout, "file start offset: %" PRId64 " video-frames\n",file_frame_offset);
 	}
 
 	// Get a pointer to the codec context for the video stream
@@ -455,32 +468,34 @@ int open_movie(char* file_name) {
 	pCodecCtx=&(pFormatCtx->streams[videoStream]->codec);
 #endif
 
+	if (!want_quiet) {
+		fprintf(stderr, "image size: %ix%i px\n", pCodecCtx->width, pCodecCtx->height);
+	}
+
 #ifdef CROPIMG
-	movie_width = pCodecCtx->width / 2; // TODO allow configuration
-	movie_height = pCodecCtx->height;
+	movie_width = (pCodecCtx->width / 2)&~1; // TODO allow configuration
+	movie_height = pCodecCtx->height &~1;
 #else
-	movie_width = pCodecCtx->width;
-	movie_height = pCodecCtx->height;
+	movie_width = pCodecCtx->width &~1;
+	movie_height = pCodecCtx->height &~1;
 #endif
 
-	movie_aspect = 0;
-	if (movie_aspect<=0.0) {
-		if (av_stream->sample_aspect_ratio.num)
-			movie_aspect = av_q2d(av_stream->sample_aspect_ratio);
-		else if (av_stream->codec->sample_aspect_ratio.num)
-			movie_aspect = av_q2d(av_stream->codec->sample_aspect_ratio);
-		else
-			movie_aspect = 0;
-	}
-	if (movie_aspect <= 0.0)
-		movie_aspect = 1.0;
-	movie_aspect *= (float)movie_width / (float)movie_height;
+	float sample_aspect = 1.0;
+
+	if (av_stream->sample_aspect_ratio.num)
+		sample_aspect = av_q2d(av_stream->sample_aspect_ratio);
+	else if (av_stream->codec->sample_aspect_ratio.num)
+		sample_aspect = av_q2d(av_stream->codec->sample_aspect_ratio);
+	else
+		sample_aspect = 1.0;
+
+	movie_aspect = sample_aspect * (float)pCodecCtx->width / (float) pCodecCtx->height;
 
 	ffctv_height = movie_height;
-	ffctv_width = ((int)rint(movie_height * movie_aspect)) & ~1;
-	if (ffctv_width > movie_width) {
+	ffctv_width = ((int)rint(pCodecCtx->height * movie_aspect)) & ~1;
+	if (ffctv_width > pCodecCtx->width) {
 		ffctv_width = movie_width;
-		ffctv_height = ((int)rint(movie_width / movie_aspect)) & ~1;
+		ffctv_height = ((int)rint(pCodecCtx->width / movie_aspect)) & ~1;
 	}
 
 // somewhere around LIBAVFORMAT_BUILD  4630 
@@ -491,7 +506,7 @@ int open_movie(char* file_name) {
 #endif
 
 	if (!want_quiet) {
-		fprintf( stderr, "movie size:  %ix%i px\n", movie_width,movie_height);
+		fprintf(stderr, "display size: %ix%i px\n", movie_width, movie_height);
 	}
 	// Find the decoder for the video stream
 	pCodec=avcodec_find_decoder(pCodecCtx->codec_id);
@@ -705,6 +720,10 @@ int my_seek_frame (AVPacket *packet, int64_t timestamp) {
 	} 
 #endif 
 
+	if (rv < 0 && (timestamp == 0 || seekflags == SEEK_CONTINUOUS)) {
+		rv = av_seek_frame(pFormatCtx, videoStream, timestamp, 0);
+	}
+
 	my_avprev = timestamp;
 	if (rv < 0) return (0); // seek failed.
 
@@ -763,7 +782,10 @@ read_frame:
 #else // test & check time-base/ framerate re-scaling
 	if ((mtsb*framerate*av_q2d(v_stream->time_base)) >= (timestamp*framerate*av_q2d(v_stream->time_base)))
 #endif
+	{
+		my_avprev = mtsb;
 		return (1); // ok!
+	}
 
 	/* skip to next frame */
 #ifdef FFDEBUG
@@ -830,7 +852,25 @@ void display_frame(int64_t timestamp, int force_update, int do_render) {
 			if(frameFinished) {
 				/* Convert the image from its native format to FMT */
 #ifdef HAVE_SWSCALE
-				sws_scale(pSWSCtx, (const uint8_t * const*)pFrame->data, pFrame->linesize, 0, pCodecCtx->height, pFrameFMT->data, pFrameFMT->linesize);
+				int dstStride[8] = {0,0,0,0,0,0,0,0};
+				switch (render_fmt) {
+					case PIX_FMT_RGBA32:
+					case PIX_FMT_BGRA32:
+						dstStride[0] = movie_width*4;
+						break;
+					case PIX_FMT_BGR24:
+						dstStride[0] = movie_width*3;
+						break;
+					case PIX_FMT_UYVY422:
+						dstStride[0] = movie_width*2;
+						break;
+					case PIX_FMT_YUV420P:
+					default:
+						dstStride[0] = movie_width;
+						dstStride[1] = movie_width/2;
+						dstStride[2] = movie_width/2;
+				}
+				sws_scale(pSWSCtx, (const uint8_t * const*)pFrame->data, pFrame->linesize, 0, pCodecCtx->height, pFrameFMT->data, dstStride);
 #else
 				img_convert((AVPicture *)pFrameFMT, render_fmt, 
 					(AVPicture*)pFrame, pCodecCtx->pix_fmt, pCodecCtx->width, 
